flupan
======


Python library to parse influenza passaging annotations.

About
-----
Influenza virus is frequency passaged prior to being sequenced. These growth conditions are recorded as shorthand passaging annotations. However, these passages are often inconsistent and not easily machine readable. This library takes individual passage history strings (Ex. M1_S3) and returns an object containing its interpretation.

Documentation
-------------
_See GitHub repo: https://github.com/clauswilke/flupan


Authors
-------
Claire D. McWhite

Claus O. Wilke



